﻿using System.Drawing;
using System.Windows.Forms;

using Steema.TeeChart.Functions;
using Steema.TeeChart.Styles;
using Steema.TeeChart.Tools;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 패스트 라인 1 시리즈
        /// </summary>
        private FastLine fastLine1;

        /// <summary>
        /// 지수 트렌드 함수
        /// </summary>
        private ExpTrendFunction expTrendFunction1;

        /// <summary>
        /// 패스트 라인 2 시리즈
        /// </summary>
        private FastLine fastLine2;

        /// <summary>
        /// 트렌드 함수
        /// </summary>
        private TrendFunction trendFunction;

        /// <summary>
        /// 패스트 라인 3 시리즈
        /// </summary>
        private FastLine fastLine3;

        /// <summary>
        /// 그리드 밴드
        /// </summary>
        private GridBand gridBand;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            #region 패스트 라인 1 시리즈를 생성한다.

            this.fastLine1 = new FastLine();

            this.fastLine1.Title = "Source";
            this.fastLine1.Color = Color.FromArgb(93, 165, 161);

            #endregion
            #region 지수 트렌드 함수를 생성한다.

            this.expTrendFunction1 = new ExpTrendFunction();

            #endregion
            #region 패스트 라인 2 시리즈를 생성한다.

            this.fastLine2 = new FastLine();

            this.fastLine2.Title      = "Exp. Trend";
            this.fastLine2.Color      = Color.FromArgb(196, 83, 49);
            this.fastLine2.DataSource = this.fastLine1;
            this.fastLine2.Function   = this.expTrendFunction1;

            #endregion
            #region 트랜드 함수를 생성한다.

            this.trendFunction = new TrendFunction();

            #endregion
            #region 패스트 라인 3 시리즈를 생성한다.

            this.fastLine3 = new FastLine();

            this.fastLine3.Title      = "Trend";
            this.fastLine3.Color      = Color.FromArgb(231, 150, 9);
            this.fastLine3.ColorEach  = false;
            this.fastLine3.DataSource = this.fastLine1;
            this.fastLine3.Function   = this.trendFunction;

            #endregion
            #region 그리드 밴드를 생성한다.

            this.gridBand = new GridBand();

            this.gridBand.Band1.Color = Color.FromArgb(127, 224, 224, 224);
            this.gridBand.Band2.Color = Color.FromArgb(127, 255, 255, 255);
            this.gridBand.Axis        = this.tChart.Axes.Left;

            #endregion
            #region 티차트를 설정한다.

            this.tChart.Tools.Add(this.gridBand);

            this.tChart.Series.Add(this.fastLine1);
            this.tChart.Series.Add(this.fastLine2);
            this.tChart.Series.Add(this.fastLine3);

            #endregion

            this.fastLine1.FillSampleValues(100);
        }

        #endregion
    }
}